==> libreoffice-7.5.7.1.tar.xz: libreoffice-7.5.7.1/vcl/source/animate/AnimationFrame.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sal/config.h>
#include <o3tl/underlyingenumvalue.hxx>
#include <tools/solar.h>
#include <vcl/animate/AnimationFrame.hxx>

BitmapChecksum AnimationFrame::GetChecksum() const
{
    BitmapChecksum nCrc = maBitmapEx.GetChecksum();
    SVBT32 aBT32;

    Int32ToSVBT32(maPositionPixel.X(), aBT32);
    nCrc = vcl_get_checksum(nCrc, aBT32, 4);

    Int32ToSVBT32(maPositionPixel.Y(), aBT32);
    nCrc = vcl_get_checksum(nCrc, aBT32, 4);

    Int32ToSVBT32(maSizePixel.Width(), aBT32);
    nCrc = vcl_get_checksum(nCrc, aBT32, 4);

    Int32ToSVBT32(maSizePixel.Height(), aBT32);
    nCrc = vcl_get_checksum(nCrc, aBT32, 4);

    Int32ToSVBT32(mnWait, aBT32);
    nCrc = vcl_get_checksum(nCrc, aBT32, 4);

    UInt32ToSVBT32(o3tl::to_underlying(meDisposal), aBT32);
    nCrc = vcl_get_checksum(nCrc, aBT32, 4);

    UInt32ToSVBT32(sal_uInt32(mbUserInput), aBT32);
    nCrc = vcl_get_checksum(nCrc, aBT32, 4);

    return nCrc;
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-7.6.5.2.tar.xz: libreoffice-7.6.5.2/vcl/source/animate/AnimationFrame.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sal/config.h>
#include <o3tl/underlyingenumvalue.hxx>
#include <tools/solar.h>
#include <vcl/animate/AnimationFrame.hxx>
#include <rtl/crc.h>

BitmapChecksum AnimationFrame::GetChecksum() const
{
    BitmapChecksum nCrc = maBitmapEx.GetChecksum();
    SVBT32 aBT32;

    Int32ToSVBT32(maPositionPixel.X(), aBT32);
    nCrc = rtl_crc32(nCrc, aBT32, 4);

    Int32ToSVBT32(maPositionPixel.Y(), aBT32);
    nCrc = rtl_crc32(nCrc, aBT32, 4);

    Int32ToSVBT32(maSizePixel.Width(), aBT32);
    nCrc = rtl_crc32(nCrc, aBT32, 4);

    Int32ToSVBT32(maSizePixel.Height(), aBT32);
    nCrc = rtl_crc32(nCrc, aBT32, 4);

    Int32ToSVBT32(mnWait, aBT32);
    nCrc = rtl_crc32(nCrc, aBT32, 4);

    UInt32ToSVBT32(o3tl::to_underlying(meDisposal), aBT32);
    nCrc = rtl_crc32(nCrc, aBT32, 4);

    UInt32ToSVBT32(sal_uInt32(mbUserInput), aBT32);
    nCrc = rtl_crc32(nCrc, aBT32, 4);

    return nCrc;
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
